#
# spec file for package kraft
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2007-2011 Klaas Freitag <freitag@kde.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           kraft
Url:            http://volle-kraft-voraus.de

Version:        0.59
Release:        1.1
Summary:        KDE software to manage office documents in the office
License:        GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Office/Other
Source0:        kraft-%{version}.tar.xz
Patch0:         fix_dup_custom_targets.diff

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if 0%{?suse_version}
Requires:       kdepim4-runtime
Requires:       libqt4-sql-sqlite
Requires:       python-pypdf
Requires:       sqlite3
%kde4_runtime_requires
%kde4_pimlibs_requires
%kde4_akonadi_requires

BuildRequires:  libctemplate-devel
BuildRequires:  libkde4-devel
BuildRequires:  libkdepimlibs4-devel
BuildRequires:  update-desktop-files
%endif

%if 0%{?fedora_version}
Requires:       kdepim-runtime
Requires:       pyPdf
Requires:       qt >= 4.7
Requires:       qt-x11 >= 4.7
Requires:       sqlite

BuildRequires:  ctemplate-devel
BuildRequires:  kdelibs-devel
BuildRequires:  kdepimlibs-devel
%endif
Requires:       python-reportlab

%description
Kraft is KDE software to help to create and manage office documents such as
offers and invoices in the small enterprise.

It supports easy document creation, templates with calculation, customer management
through the KDE addressbook, highly configurable PDF output and more.

See the website http://volle-kraft-voraus.de for more information.

%prep
%setup -q
%patch0 -p1

%build
  mkdir build
  pushd build
  %cmake_kde4 ..
  make %{?_smp_mflags}
  popd

%install
  cd build
%make_install
  cd ..
%find_lang %{name}
 chmod 755 %{buildroot}%{_datadir}/kde4/apps/kraft/tools/erml2pdf.py

%if %{?suse_version:1}0
%suse_update_desktop_file %{name} Office Finance
%endif

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%clean
  rm -rf %{buildroot}

%files -f %{name}.lang
%files
%defattr(-,root,root)
%{_bindir}/kraft
%{_bindir}/findcontact
%{_datadir}/applications/kde4/kraft.desktop
%{_datadir}/icons/*/*/*/*.png
%{_datadir}/kde4/
%if 0%{?fedora_version}
%{_datadir}/config.kcfg/databasesettings.kcfg
%{_datadir}/config.kcfg/kraftsettings.kcfg
%else
%endif

%doc AUTHORS COPYING README Releasenotes.txt TODO

%changelog
* Sat Oct 17 2015 freitag@opensuse.org
- Patch fix_dup_custom_targets.diff added to not add multiple custom
  targets, fixes building Tumbleweed.
* Thu Oct  1 2015 freitag@owncloud.com
  * New upstream version 0.59:
  - Fix discount price calculation: Do not include deleted items.
  - Fix: Mark moved items as modified, to not loose the saving
  - Fix the save loop over items, do delete items seperately
  - Fixes in the setup wizard
  - Enhance data take over when copying documents
  - Fix price calculation with discount items.
  - On doc type change, ask the user if the doc ident is to change.
  - Add GROSSSUM adn NETSUM template variables
  - Memory management fixes
  - Quite some other minor fixes
  * Patch 0001-Fix-Mark-moved-items-as-modified.patch was removed as
  it went to the codebase.
* Fri May  1 2015 freitag@opensuse.org
- Added patch named 0001-Fix-Mark-moved-items-as-modified.patch
  This fixes a bug that item move operations are not saved if the
  move was the only change on a document.
  This patch will be in the next stable release of kraft and can
  be removed from this package.
* Sun Apr  5 2015 freitag@opensuse.org
  * Update to upstream version 0.58:
  - Fix handling of slashes in the doc id template
  - Fix a bug in calculation of the VAT sum
  - Removed kraftcat library as it was unused. Easier building now.
  * Removed patch kraft_no_lib.diff from package as the changes went
  upstream and are contained in the official tarball now.
* Sun Mar 15 2015 freitag@opensuse.org
- Added a patch that does not build a lib from some sources.
  Previous builds contained a libkraftcat which was not used
  publically and also not really tested. rpmlint complained
  so removing is better.
* Sat Feb 28 2015 freitag@opensuse.org
- Fixed license abbreviations and removed INSTALL file to relax
  rpmlint
* Fri Nov  7 2014 freitag@opensuse.org
- New tarball of Kraft 0.57
  Code wise 0.57 is identical to 0.56 as should have been, but
  there have been broken tarballs of 0.56 around, so 0.57 was
  tagged to be on the save side.
* Tue Nov  4 2014 freitag@owncloud.com
  * New upstream release 0.56
  - Fix handling of custom greetings in combobox.
  - Handle document type changes correctly: Set a new ident number
  depending on the new document id
  - Fix behaviour of the greeting combobox: Do not loose custom entries
  any more
  - Add receipient email address if document is emailed
  - Fix document emailing for thunderbird
  - Fix removing of alternative- and on-demand state of items
  - Wording fixes
  - Fix Ok/Cancel for doc editor
  - Better error messages if template can not be read
  - A couple of crash fixes and memory management cleanups
* Thu May 29 2014 freitag@owncloud.com
  * New upstream release 0.55
  - Fix a bug with the PDF generation, regression in 0.54
  - Fix compiling with latest version of ctemplate
* Sun May 11 2014 freitag@opensuse.org
  * New upstream release 0.54
  - Use new address fetch job implementation that works independant
    from Nepomuk- or Baloo indexing of contacts. (KDE >= 4.12)
  - Support note-of-delivery documents (Lieferscheine) without prices.
  - Added findcontact utility
  - Generate a customer sorted document storage structure on disk
  - Improve stylesheet handling in templates, introduce CSS_IMG_PATH
  - Use environment variable KRAFT_HOME more consquentely
  - Fix tax sum calculation
  - Add customer address UID variable to number circle tags
  - Some memleak fixes
  - Add "followup document" to main menu
  - Fix installation of identity.trml
  - Allow the tags USERNAME, DATE and TIME in item templates.
  - Lots of other cleanups and fixes
* Fri Oct 11 2013 freitag@owncloud.com
  * Upstream release 0.53
  - Fix screwed tarball 0.51
  - Fixes drag and drop handling in catalog window.
  - Fixes with units, do not confuse units any more
  - Utf8 fixes
  - other minor fixes
* Sun Sep 22 2013 freitag@owncloud.com
  * New upstream release 0.51
  - Fix drag and drop in catalogues.
  - Implemented removal of sub chapters.
  - Add the content of an entire template catalog chapter to the document
    if the chapter item is selected.
  - Added a new setting "Own Identity" to allow to pick the own identity
    from the address books in an installed system.
  - Make text template loading utf8 save.
  - Reworked image-in-template example in invoice report template.
  - Fixed unit handling, no more startsWith coparison of text.
* Mon Mar 11 2013 freitag@owncloud.com
- Added a patch to fix catalog editing of the material catalog.
  With that patch, templates and sub chapters can be moved around
  using drag and drop and the changes are actually saved.
* Mon Dec 17 2012 freitag@opensuse.org
  * update to Kraft version 0.50
- Handling of individual tax rates for each document item
- bugfix: escape texts in reports correctly (reported by Lars Diel).
- bugfix: if akonadi address was not found, display proper msg.
- Proper error message if a python module is not installed but needed
  by the pdf generator.
- added button to assign an address book entry as document receiver
  for existing documents (Bug #3477467)
- bugfix: Display of number of processed sql commands in setup
  assistant (Bug #3560611)
- started to optimize database save of documents for more performant
  saves.
- bugfix: Fixed import of document items from csv lists.
- added page number on default document from page two to end.
- bugfix: Fixed mysql database setup.
- Rearragned doc type setup dialog to better display path names of
  template file and watermark file.
- bugfix: If a manual entered template has checkbox "store in template
  catalog, the template is immediately written to and catalog is
  reloaded.
- bugfix: Focus on the last added item on document edit.
* Tue Nov 29 2011 freitag@suse.com
- added patch to fix the own identity search in portal.cpp
* Fri Nov 11 2011 freitag@suse.com
- added patch to make follow-up documents and copy doc work
  again.
* Tue Nov  8 2011 freitag@suse.com
- update to upstream version 0.45
  0.45 was released as a fix for 0.44 which contains a bug in showing
  decimal places of items on the PDF document. Needs quick fix.
* Thu Nov  3 2011 freitag@suse.com
- update to upstream tarball 0.44
- Completely reworked the addressbook widget in Kraft, used in new doc
  assistant and in the "who am i" dialog: Fully Akonadi-based, works
  with various addressbooks and loads addresses way more fast.
- Completely reworked text template widget used in the document editor:
  Less bugs, more obvious gui, help texts where needed
- Fixed bug that crashed Kraft when clicking on empty catalog chapters.
- Add ability to add localized report template files, added german
  localization
- Fixed bug that numbers in the doc are not localized correctly
- Fixed bug that the doc type is not taken correctly from the new doc
  wizard
- No need any more to checkbox single item templates to move them into
  the document. Selecting is sufficient.
- Added a search line in the "who am i"-dialog
- even more bugfixes
* Wed May 25 2011 freitag@novell.com
- update to upstream tarball 0.43
* Thu Apr 14 2011 freitag@novell.com
- update to upstream tarball 0.41, incl. patch for non rpath lib dir
* Mon Mar 21 2011 freitag@novell.com
- fix for address selection (name -> realname)
- removed deb build files
* Tue Apr 13 2010 freitag@novell.com
- update to the final 0.40 tarball - harrah!
* Wed Apr  7 2010 freitag@novell.com
- update to third beta version for the 0.40 release
